@@ -1,4 +1,4 @@
-### xtable 1.4-1  (2006/10/05)
+### xtable 1.4-2  (2006/10/23)
 ###
 ### Produce LaTeX and HTML tables from R objects.
 ###
@@ -89,7 +89,7 @@ print.xtable <- function(x,type="latex",file="",append=FALSE,floating=TRUE,float
   if (length(type)>1) stop("\"type\" must have length 1")
   type <- tolower(type)
   if (!all(!is.na(match(type,c("latex","html"))))) stop("\"type\" must be in {\"latex\", \"html\"}")
-  if (!all(!is.na(match(floating.environment,c("table","sidewaystable"))))) stop("\"type\" must be in {\"latex\", \"html\"}")
+  if (!all(!is.na(match(floating.environment,c("table","sidewaystable"))))) stop("\"type\" must be in {\"table\", \"sidewaystable\"}")
   if (!all(!is.na(match(unlist(strsplit(table.placement, split="")),c("H","h","t","b","p","!"))))) {
     stop("\"table.placement\" must contain only elements of {\"h\",\"t\",\"b\",\"p\",\"!\"}")
   }
